# Python library for calibration of terahertz spectra
This is a Python library for calibration of terahertz spectra

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install toolkit in requirements.txt.


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)